package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcWlaqzcqy;
import com.ruoyi.tcZz.domain.TcWldv;
import com.ruoyi.tcZz.service.ITcWldvService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 网络大VController
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "网络大V")
@RequestMapping("/tcZz/networkEcology/wldv")
public class TcWldvController extends BaseController {
    @Autowired
    private ITcWldvService tcWldvService;

    /**
     * 查询网络大V列表
     */
    @ApiOperation("查询网络大V列表")
    @GetMapping("/list")
    public TableDataInfo list(TcWldv tcWldv) {
        startPage();
        List<TcWldv> list = tcWldvService.selectTcWldvList(tcWldv);
        return getDataTable(list);
    }

    /**
     * 导出网络大V列表
     */
    @ApiOperation("导出网络大V列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcWldv tcWldv) {
        List<TcWldv> list = tcWldvService.selectTcWldvList(tcWldv);
        ExcelUtil<TcWldv> util = new ExcelUtil<TcWldv>(TcWldv.class);
        util.exportExcel(response, list, "网络大V数据");
    }

    /**
     * 获取网络大V详细信息
     */
    @ApiOperation("获取网络大V详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcWldvService.selectTcWldvById(id));
    }

    /**
     * 新增网络大V
     */
    @ApiOperation("新增网络大V")
    @PostMapping
    public AjaxResult add(@RequestBody TcWldv tcWldv) {
        return toAjax(tcWldvService.insertTcWldv(tcWldv));
    }

    /**
     * 修改网络大V
     */
    @ApiOperation("修改网络大V")
    @PutMapping
    public AjaxResult edit(@RequestBody TcWldv tcWldv) {
        return toAjax(tcWldvService.updateTcWldv(tcWldv));
    }

    /**
     * 删除网络大V
     */
    @ApiOperation("删除网络大V")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcWldvService.deleteTcWldvByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcWldv> util = new ExcelUtil<TcWldv>(TcWldv.class);
        List<TcWldv> tcWldvList = util.importExcel(file.getInputStream());
        tcWldvService.importUser(tcWldvList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcWldvService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcWldv> util = new ExcelUtil<TcWldv>(TcWldv.class);
        util.importTemplateExcel(response, " 网络大V");
    }
}
